@@ -33,7 +33,7 @@ class StudyGroupIndex(TendenciBaseSearchIndex):
         return obj.allow_anonymous_view and obj.status == 1 \
         and obj.status_detail == 'active'
 
-    def prepare_syndicate_order(self, obj):
+    def prepare_order(self, obj):
         return obj.update_dt
 
 site.register(StudyGroup, StudyGroupIndex)
